@@ -11,8 +11,6 @@
 
 #include "conn.h"
 
-#include <string.h>
-
 #include <dbus/dbus-glib.h>
 
 #include <telepathy-glib/telepathy-glib.h>
@@ -20,6 +18,7 @@
 #include <telepathy-glib/handle-repo-static.h>
 
 #include "contact-list-manager.h"
+#include "protocol.h"
 
 static void init_aliasing (gpointer, gpointer);
 
@@ -38,12 +37,14 @@ G_DEFINE_TYPE_WITH_CODE (ExampleContactListConnection,
 enum
 {
   PROP_ACCOUNT = 1,
+  PROP_SIMULATION_DELAY,
   N_PROPS
 };
 
 struct _ExampleContactListConnectionPrivate
 {
   gchar *account;
+  guint simulation_delay;
   ExampleContactListManager *list_manager;
   gboolean away;
 };
@@ -71,6 +72,10 @@ get_property (GObject *object,
       g_value_set_string (value, self->priv->account);
       break;
 
+    case PROP_SIMULATION_DELAY:
+      g_value_set_uint (value, self->priv->simulation_delay);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, spec);
     }
@@ -92,6 +97,10 @@ set_property (GObject *object,
       self->priv->account = g_value_dup_string (value);
       break;
 
+    case PROP_SIMULATION_DELAY:
+      self->priv->simulation_delay = g_value_get_uint (value);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, spec);
     }
@@ -124,14 +133,12 @@ example_contact_list_normalize_contact (TpHandleRepoIface *repo,
                                         gpointer context,
                                         GError **error)
 {
-  if (id[0] == '\0')
-    {
-      g_set_error (error, TP_ERRORS, TP_ERROR_INVALID_HANDLE,
-          "Contact ID must not be empty");
-      return NULL;
-    }
+  gchar *normal = NULL;
 
-  return g_utf8_normalize (id, -1, G_NORMALIZE_ALL_COMPOSE);
+  if (example_contact_list_protocol_check_contact_id (id, &normal, error))
+    return normal;
+  else
+    return NULL;
 }
 
 static gchar *
@@ -221,6 +228,7 @@ create_channel_managers (TpBaseConnection *conn)
     EXAMPLE_CONTACT_LIST_MANAGER (g_object_new (
           EXAMPLE_TYPE_CONTACT_LIST_MANAGER,
           "connection", conn,
+          "simulation-delay", self->priv->simulation_delay,
           NULL));
 
   g_signal_connect (self->priv->list_manager, "alias-updated",
@@ -280,7 +288,7 @@ aliasing_fill_contact_attributes (GObject *object,
       TpHandle contact = g_array_index (contacts, guint, i);
 
       tp_contacts_mixin_set_contact_attribute (attributes, contact,
-          TP_IFACE_CONNECTION_INTERFACE_ALIASING "/alias",
+          TP_TOKEN_CONNECTION_INTERFACE_ALIASING_ALIAS,
           tp_g_value_slice_new_string (
             example_contact_list_manager_get_alias (self->priv->list_manager,
               contact)));
@@ -396,17 +404,26 @@ set_own_status (GObject *object,
   return TRUE;
 }
 
+static const gchar *interfaces_always_present[] = {
+    TP_IFACE_CONNECTION_INTERFACE_ALIASING,
+    TP_IFACE_CONNECTION_INTERFACE_CONTACTS,
+    TP_IFACE_CONNECTION_INTERFACE_PRESENCE,
+    TP_IFACE_CONNECTION_INTERFACE_REQUESTS,
+    TP_IFACE_CONNECTION_INTERFACE_SIMPLE_PRESENCE,
+    NULL };
+
+const gchar * const *
+example_contact_list_connection_get_possible_interfaces (void)
+{
+  /* in this example CM we don't have any extra interfaces that are sometimes,
+   * but not always, present */
+  return interfaces_always_present;
+}
+
 static void
 example_contact_list_connection_class_init (
     ExampleContactListConnectionClass *klass)
 {
-  static const gchar *interfaces_always_present[] = {
-      TP_IFACE_CONNECTION_INTERFACE_ALIASING,
-      TP_IFACE_CONNECTION_INTERFACE_CONTACTS,
-      TP_IFACE_CONNECTION_INTERFACE_PRESENCE,
-      TP_IFACE_CONNECTION_INTERFACE_REQUESTS,
-      TP_IFACE_CONNECTION_INTERFACE_SIMPLE_PRESENCE,
-      NULL };
   TpBaseConnectionClass *base_class = (TpBaseConnectionClass *) klass;
   GObjectClass *object_class = (GObjectClass *) klass;
   GParamSpec *param_spec;
@@ -431,6 +448,13 @@ example_contact_list_connection_class_init (
       G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB);
   g_object_class_install_property (object_class, PROP_ACCOUNT, param_spec);
 
+  param_spec = g_param_spec_uint ("simulation-delay", "Simulation delay",
+      "Delay between simulated network events",
+      0, G_MAXUINT32, 1000,
+      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+  g_object_class_install_property (object_class, PROP_SIMULATION_DELAY,
+      param_spec);
+
   tp_contacts_mixin_class_init (object_class,
       G_STRUCT_OFFSET (ExampleContactListConnectionClass, contacts_mixin));
   tp_presence_mixin_class_init (object_class,
