@@ -368,16 +368,13 @@ tp_handle_channels_context_class_init (
   /**
    * TpHandleChannelsContext:user-action-time:
    *
-   * The User_Action_Time that have been passed to HandleChannels.
+   * The time at which user action occurred, or one of the
+   * special values %TP_USER_ACTION_TIME_NOT_USER_ACTION or
+   * %TP_USER_ACTION_TIME_CURRENT_TIME
+   * (see #TpAccountChannelRequest:user-action-time for details)
+   *
    * Read-only except during construction.
    *
-   * If 0, the action doesn't involve any user action. Clients
-   * SHOULD avoid stealing focus when presenting the channel.
-   *
-   * If #G_MAXINT64: clients SHOULD behave as though the user
-   * action happened at the current time, e.g. a client MAY
-   * request that its window gains focus.
-   *
    * Since: 0.11.6
    */
   param_spec = g_param_spec_int64 ("user-action-time",
@@ -605,7 +602,7 @@ out:
 }
 
 static void
-channel_prepare_cb (GObject *source,
+hcc_channel_prepare_cb (GObject *source,
     GAsyncResult *result,
     gpointer user_data)
 {
@@ -630,11 +627,11 @@ out:
 }
 
 static void
-context_prepare (TpHandleChannelsContext *self)
+context_prepare (TpHandleChannelsContext *self,
+    const GQuark *account_features,
+    const GQuark *connection_features,
+    const GQuark *channel_features)
 {
-  GQuark account_features[] = { TP_ACCOUNT_FEATURE_CORE, 0 };
-  GQuark conn_features[] = { TP_CONNECTION_FEATURE_CORE, 0 };
-  GQuark channel_features[] = { TP_CHANNEL_FEATURE_CORE, 0 };
   guint i;
 
   self->priv->num_pending = 2;
@@ -642,7 +639,7 @@ context_prepare (TpHandleChannelsContext *self)
   tp_proxy_prepare_async (self->account, account_features,
       account_prepare_cb, g_object_ref (self));
 
-  tp_proxy_prepare_async (self->connection, conn_features,
+  tp_proxy_prepare_async (self->connection, connection_features,
       conn_prepare_cb, g_object_ref (self));
 
   for (i = 0; i < self->channels->len; i++)
@@ -652,13 +649,16 @@ context_prepare (TpHandleChannelsContext *self)
       self->priv->num_pending++;
 
       tp_proxy_prepare_async (channel, channel_features,
-          channel_prepare_cb, g_object_ref (self));
+          hcc_channel_prepare_cb, g_object_ref (self));
     }
 }
 
 void
 _tp_handle_channels_context_prepare_async (
     TpHandleChannelsContext *self,
+    const GQuark *account_features,
+    const GQuark *connection_features,
+    const GQuark *channel_features,
     GAsyncReadyCallback callback,
     gpointer user_data)
 {
@@ -670,7 +670,8 @@ _tp_handle_channels_context_prepare_async (
   self->priv->result = g_simple_async_result_new (G_OBJECT (self),
       callback, user_data, _tp_handle_channels_context_prepare_async);
 
-  context_prepare (self);
+  context_prepare (self, account_features, connection_features,
+      channel_features);
 }
 
 gboolean
@@ -695,3 +696,27 @@ _tp_handle_channels_context_prepare_finish (
 
   return TRUE;
 }
+
+/**
+ * tp_handle_channels_context_get_handler_info:
+ * @self: a channel-handling context
+ *
+ * Return any extra information that accompanied this request to handle
+ * channels (the Handler_Info argument from the HandleChannels D-Bus method).
+ * Well-known keys for this map will be defined by the Telepathy D-Bus
+ * Interface Specification; at the time of writing, none have been defined.
+ *
+ * The returned hash table is only valid for as long as @self is.
+ *
+ * Returns: (transfer none) (element-type utf8 GObject.Value): extensible
+ *  extra handler information, in a form suitable for use with
+ *  tp_asv_get_string() etc.
+ *
+ * Since: 0.11.14
+ */
+const GHashTable *
+tp_handle_channels_context_get_handler_info (TpHandleChannelsContext *self)
+{
+  g_return_val_if_fail (TP_IS_HANDLE_CHANNELS_CONTEXT (self), NULL);
+  return self->handler_info;
+}
