@@ -24,7 +24,7 @@
  * @short_description: a mixin implementation of the text channel type and the
  *  Messages interface
  * @see_also: #TpSvcChannelTypeText, #TpSvcChannelInterfaceMessages,
- *  <link linkend="dbus-properties-mixin">TpDBusPropertiesMixin</link>
+ *  <link linkend="telepathy-glib-dbus-properties-mixin">TpDBusPropertiesMixin</link>
  *
  * This mixin can be added to a channel GObject class to implement the
  * text channel type (with the Messages interface) in a general way.
@@ -393,9 +393,9 @@ tp_message_ref_handle (TpMessage *self,
 static void
 tp_message_ref_handles (TpMessage *self,
                         TpHandleType handle_type,
-                        TpIntSet *handles)
+                        TpIntset *handles)
 {
-  TpIntSet *updated;
+  TpIntset *updated;
 
   g_return_if_fail (handle_type > TP_HANDLE_TYPE_NONE);
   g_return_if_fail (handle_type < NUM_TP_HANDLE_TYPES);
