@@ -360,6 +360,7 @@ tp_protocol_finalize (GObject *object)
   _tp_connection_manager_protocol_free_contents (&self->priv->protocol_struct);
   g_free (self->priv->vcard_field);
   g_free (self->priv->english_name);
+  g_free (self->priv->icon_name);
 
   if (self->priv->protocol_properties != NULL)
     g_hash_table_unref (self->priv->protocol_properties);
@@ -562,14 +563,14 @@ tp_protocol_class_init (TpProtocolClass *klass)
    * TpProtocol:english-name:
    *
    * The name of the protocol in a form suitable for display to users,
-   * such as "AIM" or "Yahoo!", or a string based on #TpProtocol:name
+   * such as "AIM" or "Yahoo!", or a string based on #TpProtocol:protocol-name
    * (currently constructed by putting the first character in title case,
    * but this is not guaranteed) if no better name is available or the
    * %TP_PROTOCOL_FEATURE_CORE feature has not been prepared.
    *
    * This is effectively in the C locale (international English); user
    * interfaces requiring a localized protocol name should look one up in their
-   * own message catalog based on either #TpProtocol:name or
+   * own message catalog based on either #TpProtocol:protocol-name or
    * #TpProtocol:english-name, but should use this English version as a
    * fallback if no translated version can be found.
    *
@@ -1184,7 +1185,7 @@ _tp_protocol_parse_channel_class (GKeyFile *file,
       gchar *value = NULL;
       gchar *property = NULL;
       const gchar *dbus_type;
-      GValue *v = NULL;
+      GValue *v = g_slice_new0 (GValue);
 
       value = g_key_file_get_string (file, group, *key, NULL);
 
@@ -1208,7 +1209,12 @@ _tp_protocol_parse_channel_class (GKeyFile *file,
 
 cleanup:
       if (v != NULL)
-        tp_g_value_slice_free (v);
+        {
+          if (G_IS_VALUE (v))
+            tp_g_value_slice_free (v);
+          else
+            g_slice_free (GValue, v);
+        }
 
       g_free (property);
       g_free (value);
@@ -1399,6 +1405,9 @@ _tp_protocol_parse_manager_file (GKeyFile *file,
 
   g_strfreev (rcc_groups);
 
+  tp_asv_take_boxed (immutables, TP_PROP_PROTOCOL_REQUESTABLE_CHANNEL_CLASSES,
+      TP_ARRAY_TYPE_REQUESTABLE_CHANNEL_CLASS_LIST, rccs);
+
   if (protocol_name != NULL)
     *protocol_name = g_strdup (name);
 
